==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/bs-Latn.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y. G",
    GyMMM => "MMM y. G",
    GyMMMEd => "E, d. MMM y. G",
    GyMMMd => "d. MMM y. G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss (v)",
    Hmv => "HH:mm (v)",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    MMMMEd => "E, d. MMMM",
    "MMMMW-count-few" => "W. 'sedmica' 'mjesec' MMMM",
    "MMMMW-count-one" => "W. 'sedmica' 'mjesec' MMMM",
    "MMMMW-count-other" => "W. 'sedmica' 'mjesec' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMdd => "d. M.",
    Md => "d.M.",
    d => "d.",
    h => "h a",
    hm => "hh:mm a",
    hms => "hh:mm:ss a",
    hmsv => "h:mm:ss a (v)",
    hmv => "h:mm a (v)",
    ms => "mm:ss",
    y => "y.",
    yM => "MM/y",
    yMEd => "E, d.M.y.",
    yMM => "M/y",
    yMMM => "MMM y.",
    yMMMEd => "E, d. MMM y.",
    yMMMM => "LLLL y.",
    yMMMd => "d. MMM y.",
    yMd => "d.M.y.",
    yQQQ => "QQQ y.",
    yQQQQ => "QQQQ y.",
    "yw-count-few" => "w. 'sedmica' 'u' Y.",
    "yw-count-one" => "w. 'sedmica' 'u' Y.",
    "yw-count-other" => "w. 'sedmica' 'u' Y.",
  },
  code => "bs-Latn",
  date_format_full => "EEEE, d. MMMM y.",
  date_format_long => "d. MMMM y.",
  date_format_medium => "d. MMM y.",
  date_format_short => "d. M. y.",
  datetime_format_full => "{1} 'u' {0}",
  datetime_format_long => "{1} 'u' {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "pon",
    "uto",
    "sri",
    "\N{U+010d}et",
    "pet",
    "sub",
    "ned",
  ],
  day_format_narrow => [
    "P",
    "U",
    "S",
    "\N{U+010c}",
    "P",
    "S",
    "N",
  ],
  day_format_wide => [
    "ponedjeljak",
    "utorak",
    "srijeda",
    "\N{U+010d}etvrtak",
    "petak",
    "subota",
    "nedjelja",
  ],
  day_stand_alone_abbreviated => [
    "pon",
    "uto",
    "sri",
    "\N{U+010d}et",
    "pet",
    "sub",
    "ned",
  ],
  day_stand_alone_narrow => [
    "p",
    "u",
    "s",
    "\N{U+010d}",
    "p",
    "s",
    "n",
  ],
  day_stand_alone_wide => [
    "ponedjeljak",
    "utorak",
    "srijeda",
    "\N{U+010d}etvrtak",
    "petak",
    "subota",
    "nedjelja",
  ],
  era_abbreviated => [
    "p. n. e.",
    "n. e.",
  ],
  era_narrow => [
    "p.n.e.",
    "n. e.",
  ],
  era_wide => [
    "prije nove ere",
    "nove ere",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Bosnian",
  month_format_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "maj",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "dec",
  ],
  month_format_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mart",
    "april",
    "maj",
    "juni",
    "juli",
    "august",
    "septembar",
    "oktobar",
    "novembar",
    "decembar",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "maj",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "dec",
  ],
  month_stand_alone_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mart",
    "april",
    "maj",
    "juni",
    "juli",
    "august",
    "septembar",
    "oktobar",
    "novembar",
    "decembar",
  ],
  name => "Bosnian Latin",
  native_language => "bosanski",
  native_name => "bosanski latinica",
  native_script => "latinica",
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "KV1",
    "KV2",
    "KV3",
    "KV4",
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_format_wide => [
    "Prvi kvartal",
    "Drugi kvartal",
    "Tre\N{U+0107}i kvartal",
    "\N{U+010c}etvrti kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "KV1",
    "KV2",
    "KV3",
    "KV4",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "Prvi kvartal",
    "Drugi kvartal",
    "Tre\N{U+0107}i kvartal",
    "\N{U+010c}etvrti kvartal",
  ],
  script => "Latin",
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.37.tar.gz: DateTime-Locale-1.37/share/bs-Latn.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d.",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y. G",
    GyMMM => "MMM y. G",
    GyMMMEd => "E, d. MMM y. G",
    GyMMMd => "d. MMM y. G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss (v)",
    Hmv => "HH:mm (v)",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    MMMMEd => "E, d. MMMM",
    "MMMMW-count-few" => "W. 'sedmica' 'mjesec' MMMM",
    "MMMMW-count-one" => "W. 'sedmica' 'mjesec' MMMM",
    "MMMMW-count-other" => "W. 'sedmica' 'mjesec' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMdd => "d. M.",
    Md => "d.M.",
    d => "d.",
    h => "h\N{U+202f}a",
    hm => "hh:mm\N{U+202f}a",
    hms => "hh:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a (v)",
    hmv => "h:mm\N{U+202f}a (v)",
    ms => "mm:ss",
    y => "y.",
    yM => "MM/y",
    yMEd => "E, d.M.y.",
    yMM => "M/y",
    yMMM => "MMM y.",
    yMMMEd => "E, d. MMM y.",
    yMMMM => "LLLL y.",
    yMMMd => "d. MMM y.",
    yMd => "d.M.y.",
    yQQQ => "QQQ y.",
    yQQQQ => "QQQQ y.",
    "yw-count-few" => "w. 'sedmica' 'u' Y.",
    "yw-count-one" => "w. 'sedmica' 'u' Y.",
    "yw-count-other" => "w. 'sedmica' 'u' Y.",
  },
  code => "bs-Latn",
  date_format_full => "EEEE, d. MMMM y.",
  date_format_long => "d. MMMM y.",
  date_format_medium => "d. MMM y.",
  date_format_short => "d. M. y.",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "pon",
    "uto",
    "sri",
    "\N{U+010d}et",
    "pet",
    "sub",
    "ned",
  ],
  day_format_narrow => [
    "P",
    "U",
    "S",
    "\N{U+010c}",
    "P",
    "S",
    "N",
  ],
  day_format_wide => [
    "ponedjeljak",
    "utorak",
    "srijeda",
    "\N{U+010d}etvrtak",
    "petak",
    "subota",
    "nedjelja",
  ],
  day_stand_alone_abbreviated => [
    "pon",
    "uto",
    "sri",
    "\N{U+010d}et",
    "pet",
    "sub",
    "ned",
  ],
  day_stand_alone_narrow => [
    "p",
    "u",
    "s",
    "\N{U+010d}",
    "p",
    "s",
    "n",
  ],
  day_stand_alone_wide => [
    "ponedjeljak",
    "utorak",
    "srijeda",
    "\N{U+010d}etvrtak",
    "petak",
    "subota",
    "nedjelja",
  ],
  era_abbreviated => [
    "p. n. e.",
    "n. e.",
  ],
  era_narrow => [
    "p.n.e.",
    "n. e.",
  ],
  era_wide => [
    "prije nove ere",
    "nove ere",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Bosnian",
  month_format_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "maj",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "dec",
  ],
  month_format_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mart",
    "april",
    "maj",
    "juni",
    "juli",
    "august",
    "septembar",
    "oktobar",
    "novembar",
    "decembar",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "maj",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "dec",
  ],
  month_stand_alone_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mart",
    "april",
    "maj",
    "juni",
    "juli",
    "august",
    "septembar",
    "oktobar",
    "novembar",
    "decembar",
  ],
  name => "Bosnian Latin",
  native_language => "bosanski",
  native_name => "bosanski latinica",
  native_script => "latinica",
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "KV1",
    "KV2",
    "KV3",
    "KV4",
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_format_wide => [
    "Prvi kvartal",
    "Drugi kvartal",
    "Tre\N{U+0107}i kvartal",
    "\N{U+010c}etvrti kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "KV1",
    "KV2",
    "KV3",
    "KV4",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "Prvi kvartal",
    "Drugi kvartal",
    "Tre\N{U+0107}i kvartal",
    "\N{U+010c}etvrti kvartal",
  ],
  script => "Latin",
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
